# from pythagoras._220_data_portals import (
#     DataPortal)
# from pythagoras import _PortalTester
# from parameterizable import smoketest_parameterizable_class
#
#
# def test_basic_portal_get_params(tmpdir):
#     with _PortalTester(DataPortal, root_dict = tmpdir):
#         smoketest_parameterizable_class(DataPortal)
#
